#!/usr/bin/env python
import unittest
import logging
import os.path

from urllib.parse import quote

from p2.logging import Logger, HttpLogger
from p2.tools.prepare_db import setUpDB, tearDownDB

class TestP2logging(unittest.TestCase):
    """Tests for `p2.logging` package."""

    def SetUp(self):
        setUpDB()

    def test_file_logger(self):
        log_obj = Logger(name=__name__, level=logging.INFO)
        logger = log_obj.getLogger()
        test_logger(logger, "file handler test")
        self.assertTrue(os.path.exists('./tests.test_p2_logging.log'))
        with open('./tests.test_p2_logging.log') as f:
            text = f.read()
            self.assertIn('handler', text)

    def test_http_logger(self):
        log_obj = HttpLogger(
            silent = False,
            token = '1234',
            name = 'test-http-log')
        logger = log_obj.getLogger()
        test_logger(logger, "http handler log")
        test_logger(logger, "http handler again")

    def test_http_logger_long_message(self):
        log_obj = HttpLogger(
            silent = False,
            token = '1234',
            name = 'test-http-log')
        logger = log_obj.getLogger()
        test_logger(logger, """
            This is quite a long,
            multiline message
            """)


def test_logger(logger, msg: str):
    logger.info(msg)

